Rdocumentation
powered by
Learn R Programming
finstr (version 0.1.2.9000)
other: Other elements
Description
Used inside expose function to select all other elements
Usage
other(...)
Arguments
...
element IDs from element hierarchy
Value
Lazy object with function to select elements from statement x