Rdocumentation
powered by
Learn R Programming
finstr (version 0.1.2.9000)
proportional: Proportional values
Description
Every value in the financial statement is divided by topmost parent's value
Usage
proportional(x, digits = NULL)
Arguments
x
a statement object
digits
if specified number of digits to round the result